<?php
/**
 * A cache file for partial free/busy information.
 *
 * PHP version 5
 *
 * @category Kolab
 * @package  Kolab_FreeBusy
 * @author   Steffen Hansen <steffen@klaralvdalens-datakonsult.se>
 * @author   Gunnar Wrobel <wrobel@pardus.de>
 * @license  http://www.fsf.org/copyleft/lgpl.html LGPL
 * @link     http://pear.horde.org/index.php?package=Kolab_FreeBusy
 */

/**
 * A cache file for partial free/busy information.
 *
 * $Horde: framework/Kolab_FreeBusy/lib/Horde/Kolab/FreeBusy/Cache/File/pvcal.php,v 1.1.2.2 2010-06-15 08:10:40 wrobel Exp $
 *
 * Copyright 2004-2008 Klarälvdalens Datakonsult AB
 *
 * See the enclosed file COPYING for license information (LGPL). If you
 * did not receive this file, see http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 *
 * @category Kolab
 * @package  Kolab_FreeBusy
 * @author   Steffen Hansen <steffen@klaralvdalens-datakonsult.se>
 * @author   Gunnar Wrobel <wrobel@pardus.de>
 * @license  http://www.fsf.org/copyleft/lgpl.html LGPL
 * @link     http://pear.horde.org/index.php?package=Kolab_FreeBusy
 */
class Horde_Kolab_FreeBusy_Cache_File_pvcal extends Horde_Kolab_FreeBusy_Cache_File {

    /**
     * The suffix of this cache file.
     *
     * @var string
     */
    var $_suffix = 'pvc';

    /**
     * Store partial free/busy infomation in the cache file.
     *
     * @param Horde_iCalendar $pvcal A reference to the data object.
     *
     * @return boolean|PEAR_Error True if successful.
     */
    function storePVcal(&$pvcal)
    {
        return $this->store($pvcal);
    }

    /**
     * Load partial free/busy data from the cache file.
     *
     * @param boolean $extended Should the extended information be retrieved?
     *
     * @return Horde_iCalendar|PEAR_Error The data retrieved from the cache file.
     */
    function &loadPVcal($extended)
    {
        $pvcal = $this->load();
        if (is_a($pvcal, 'PEAR_Error')) {
            return $pvcal;
        }
        if (!$extended) {
            $components = &$pvcal->getComponents();
            foreach ($components as $component) {
                if ($component->getType() == 'vFreebusy') {
                    $component->_extraParams = array();
                }
            }
        }
        return $pvcal;
    }

    /**
     * Return the last modification date of the cache file.
     *
     * @return int The last modification date.
     */
    function getMtime()
    {
        if (file_exists($this->_file)) {
            return filemtime($this->_file);
        } else {
            return -1;
        }
    }
}
